searchData={"items":[{"type":"module","title":"Qtrace","doc":"Quick function latency analysis and visualization based on Erlang tracing.\n\n`Qtrace` traces function calls and collects latency measurements. Uses\nhistogram-based aggregation to provide quantile analysis (P50, P95, P99)\nand terminal-based visualization of performance distributions.","ref":"Qtrace.html"},{"type":"module","title":"Usage - Qtrace","doc":"session = Qtrace.start_session(:all)\n    Qtrace.trace_function(session, MyApp, :my_function, 2)\n    Qtrace.trace_function(session, MyApp, :another_function, 1)\n\n    # ... run your code ...\n\n    Qtrace.plot_all_histograms(session)\n\n    # Getting p10\n    Qtrace.get_quantile(session, 0.10, MyApp, :my_function, 2)","ref":"Qtrace.html#module-usage"},{"type":"module","title":"Example output - Qtrace","doc":"```txt\nLatency Histogram: Qtrace.Demo.web_request/0\n================================================================================\n            0              13             26             39             52\n      5.9ms  │███ (3)\n      6.9ms  │█ (1)\n      8.1ms  │██ (2)\n      10.3ms │█ (1)\n      11.2ms │██████ (5)\n      12.1ms │█████ (4)\n      13.2ms │███ (3)\n      14.2ms │███████ (6)\n      15.4ms │████████████████ (14)\n      16.7ms │█████████████████ (15)\n      18.1ms │████████████████████ (17)\n      19.6ms │█████████████████████████████████ (29)\n      21.3ms │██████████████████████████████████████████████████████████ (50)\n      23.0ms │██████████████████████████████████████████ (36)\n      24.9ms │███████████████████████████████████████████████ (41)\n      27.0ms │████████████████████████████████████████████████████████████ (52)\n      29.3ms │█████████████████████████████████████████████████████████ (49)\n      31.7ms │███████████████████████████████████████████████████████████ (51)\n      34.4ms │██████████████████████████████████████ (33)\n      37.2ms │████████████████████████████████████████ (35)\n      40.3ms │████████████████████████ (21)\n      43.7ms │███████ (6)\n      47.3ms │███ (3)\n      51.3ms │██ (2)\n    134.0ms  │██ (2)\n    157.2ms  │█ (1)\n    199.9ms  │█ (1)\n    216.6ms  │█████████ (8)\n    234.6ms  │██ (2)\n    254.2ms  │██ (2)\n    275.4ms  │███ (3)\n    298.3ms  │██ (2)\n    323.2ms  │██ (2)\n             └────────────────────────────────────────────────────────────\n            0              13             26             39             52\nStats:\n  Min: 5.9ms\n  Max: 323.2ms\n  Samples: 502\n  P50: 27.0ms\n  P95: 47.3ms\n  P99: 275.4ms\n```","ref":"Qtrace.html#module-example-output"},{"type":"module","title":"Session Management - Qtrace","doc":"Tracing is automatically stopped when the trace session gets garbage collected.\nThe trace process may live for a bit longer: it lives for up to two minutes of\ninactivity.\n\nYou can also stop sessions or clean up trace data manually:\n\n    Qtrace.stop_session(session) # Stop the trace session\n    Qtrace.cleanup(session)      # Stop the tracer process that stores the results\n\nNotice that, in some situations, **you may need to ensure that the session doesn't\nget garbage collected** to avoid the trace stopping unexpectedly.","ref":"Qtrace.html#module-session-management"},{"type":"module","title":"Notes - Qtrace","doc":"- Sessions auto-stop when querying results\n- Measurements are in microseconds\n- Buckets have an error of up to 4%","ref":"Qtrace.html#module-notes"},{"type":"function","title":"Qtrace.add_processes/2","doc":"Adds processes to an existing tracing session.","ref":"Qtrace.html#add_processes/2"},{"type":"function","title":"Example - Qtrace.add_processes/2","doc":"session = Qtrace.start_session(:existing)\n    Qtrace.add_processes(session, :new)  # Now traces existing + new processes","ref":"Qtrace.html#add_processes/2-example"},{"type":"function","title":"Qtrace.cleanup/1","doc":"Stops the tracer process for a session.","ref":"Qtrace.html#cleanup/1"},{"type":"function","title":"Example - Qtrace.cleanup/1","doc":"session = Qtrace.start_session(:all)\n    # ... do tracing work ...\n    Qtrace.cleanup(session)  # Immediately stop the tracer","ref":"Qtrace.html#cleanup/1-example"},{"type":"function","title":"Qtrace.get_histogram/4","doc":"Builds histogram data from traced function measurements.\n\nReturns a `%Qtrace.Histogram{}` struct or `nil` if no data available.","ref":"Qtrace.html#get_histogram/4"},{"type":"function","title":"Qtrace.get_quantile/5","doc":"Gets a quantile from traced function performance data. Returns latency in microseconds.","ref":"Qtrace.html#get_quantile/5"},{"type":"function","title":"Examples - Qtrace.get_quantile/5","doc":"# Get median latency (P50)\n    p50 = Qtrace.get_quantile(session, 0.5, MyApp, :my_function, 1)\n\n    # Get 95th percentile\n    p95 = Qtrace.get_quantile(session, 0.95, MyApp, :my_function, 1)","ref":"Qtrace.html#get_quantile/5-examples"},{"type":"function","title":"Qtrace.plot_all_histograms/2","doc":"Displays histograms for all traced functions.","ref":"Qtrace.html#plot_all_histograms/2"},{"type":"function","title":"Options - Qtrace.plot_all_histograms/2","doc":"- `:width` - Width of the histogram bars (default: 60)","ref":"Qtrace.html#plot_all_histograms/2-options"},{"type":"function","title":"Qtrace.plot_histogram/5","doc":"Displays a histogram of latency measurements in the terminal.","ref":"Qtrace.html#plot_histogram/5"},{"type":"function","title":"Options - Qtrace.plot_histogram/5","doc":"- `:width` - Width of the histogram bars (default: 60)","ref":"Qtrace.html#plot_histogram/5-options"},{"type":"function","title":"Example - Qtrace.plot_histogram/5","doc":"Qtrace.plot_histogram(session, MyApp, :my_function, 1)","ref":"Qtrace.html#plot_histogram/5-example"},{"type":"function","title":"Qtrace.remove_processes/2","doc":"Removes processes from an existing tracing session.","ref":"Qtrace.html#remove_processes/2"},{"type":"function","title":"Example - Qtrace.remove_processes/2","doc":"session = Qtrace.start_session(:all)\n    Qtrace.remove_processes(session, :new)  # Stop tracing new processes","ref":"Qtrace.html#remove_processes/2-example"},{"type":"function","title":"Qtrace.start_session/1","doc":"Starts a new tracing session.","ref":"Qtrace.html#start_session/1"},{"type":"function","title":"Parameters - Qtrace.start_session/1","doc":"- `processes` - Which processes to trace (`:all`, `:existing`, `:new`, or a `pid()`)","ref":"Qtrace.html#start_session/1-parameters"},{"type":"function","title":"Returns - Qtrace.start_session/1","doc":"Returns a `Qtrace.Session.t()` struct containing the session details. If this struct\nis garbage collected, the trace stops.","ref":"Qtrace.html#start_session/1-returns"},{"type":"function","title":"Examples - Qtrace.start_session/1","doc":"# Trace all processes\n    session = Qtrace.start_session(:all)\n\n    # Trace only existing processes with a custom name\n    session = Qtrace.start_session(:existing, :my_trace_session)\n\n    # Trace a specific process\n    session = Qtrace.start_session(self())","ref":"Qtrace.html#start_session/1-examples"},{"type":"function","title":"Qtrace.stop_session/1","doc":"Stops a tracing session. Trace results remain available until cleanup.","ref":"Qtrace.html#stop_session/1"},{"type":"function","title":"Example - Qtrace.stop_session/1","doc":"session = Qtrace.start_session(:all)\n    # ... do tracing work ...\n    Qtrace.stop_session(session)","ref":"Qtrace.html#stop_session/1-example"},{"type":"function","title":"Qtrace.trace_function/4","doc":"Enables tracing for a specific function.","ref":"Qtrace.html#trace_function/4"},{"type":"function","title":"Example - Qtrace.trace_function/4","doc":"session = Qtrace.start_session(:all)\n    Qtrace.trace_function(session, Enum, :map, 2)\n\n    # Now all calls to Enum.map/2 will be traced","ref":"Qtrace.html#trace_function/4-example"},{"type":"function","title":"Restrictions - Qtrace.trace_function/4","doc":"Some modules cannot be traced:\n- `:tracer`\n- `Qtrace` and its submodules\n- `DogSketch.SimpleDog`","ref":"Qtrace.html#trace_function/4-restrictions"},{"type":"module","title":"Qtrace.Histogram","doc":"Histogram generated by using `Qtrace.get_histogram/4`","ref":"Qtrace.Histogram.html"},{"type":"type","title":"Qtrace.Histogram.t/0","doc":"","ref":"Qtrace.Histogram.html#t:t/0"},{"type":"module","title":"Qtrace.Session","doc":"Represents a trace session","ref":"Qtrace.Session.html"},{"type":"type","title":"Qtrace.Session.t/0","doc":"","ref":"Qtrace.Session.html#t:t/0"},{"type":"extras","title":"Qtrace","doc":"# Qtrace\n\nQuick function latency analysis and visualization based on Erlang tracing.\n\nTraces function calls and collects latency measurements in microseconds. Uses histogram-based aggregation to provide quantile analysis (P50, P95, P99) and terminal-based visualization of performance distributions across multiple functions.","ref":"readme.html"},{"type":"extras","title":"Usage - Qtrace","doc":"```elixir\n# Start a tracing session, tracing all processes\nsession = Qtrace.start_session(:all)\n\n# Trace specific functions\nQtrace.trace_function(session, MyApp, :my_function, 2)\nQtrace.trace_function(session, MyApp, :another_function, 1)\n\n# ... run your code ...\n\n# Visualize all traced functions\nQtrace.plot_all_histograms(session)\n\n# Get specific quantiles\np95 = Qtrace.get_quantile(session, 0.95, MyModule, :my_function, 2)\n```","ref":"readme.html#usage"},{"type":"extras","title":"Example Output - Qtrace","doc":"```txt\nLatency Histogram: Qtrace.Demo.web_request/0\n================================================================================\n            0              13             26             39             52\n      5.9ms  │███ (3)\n      6.9ms  │█ (1)\n      8.1ms  │██ (2)\n      10.3ms │█ (1)\n      11.2ms │██████ (5)\n      12.1ms │█████ (4)\n      13.2ms │███ (3)\n      14.2ms │███████ (6)\n      15.4ms │████████████████ (14)\n      16.7ms │█████████████████ (15)\n      18.1ms │████████████████████ (17)\n      19.6ms │█████████████████████████████████ (29)\n      21.3ms │██████████████████████████████████████████████████████████ (50)\n      23.0ms │██████████████████████████████████████████ (36)\n      24.9ms │███████████████████████████████████████████████ (41)\n      27.0ms │████████████████████████████████████████████████████████████ (52)\n      29.3ms │█████████████████████████████████████████████████████████ (49)\n      31.7ms │███████████████████████████████████████████████████████████ (51)\n      34.4ms │██████████████████████████████████████ (33)\n      37.2ms │████████████████████████████████████████ (35)\n      40.3ms │████████████████████████ (21)\n      43.7ms │███████ (6)\n      47.3ms │███ (3)\n      51.3ms │██ (2)\n    134.0ms  │██ (2)\n    157.2ms  │█ (1)\n    199.9ms  │█ (1)\n    216.6ms  │█████████ (8)\n    234.6ms  │██ (2)\n    254.2ms  │██ (2)\n    275.4ms  │███ (3)\n    298.3ms  │██ (2)\n    323.2ms  │██ (2)\n              └────────────────────────────────────────────────────────────\n            0              13             26             39             52\nStats:\n  Min: 5.9ms\n  Max: 323.2ms\n  Samples: 502\n  P50: 27.0ms\n  P95: 47.3ms\n  P99: 275.4ms\n```","ref":"readme.html#example-output"},{"type":"extras","title":"Installation - Qtrace","doc":"Add `qtrace` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:qtrace, \"~> 1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Documentation - Qtrace","doc":"Full documentation is available at [https://hexdocs.pm/qtrace](https://hexdocs.pm/qtrace).","ref":"readme.html#documentation"},{"type":"extras","title":"License - Qtrace","doc":"MIT License","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}